package main

import "os"
import "math"
import "image"
import "image/png"
import "git.tebibyte.media/tomo/ggfx"

func main () {
	img := image.NewRGBA(image.Rect(0, 0, 300, 300))
	canvas := ggfx.Image[uint8] {
		Pix:    img.Pix,
		Stride: img.Stride,
		Bounds: img.Rect,
		Width:  4,
	}
	black  := []uint8 { 0,   0,   0, 255 }
	yellow := []uint8 { 255, 255, 0, 255 }
	midpoint := image.Pt(canvas.Bounds.Dx() / 2, canvas.Bounds.Dy() / 2)

	face := circle(32, 100, midpoint)
	canvas.FillPolygon(yellow, face...)
	canvas.StrokePolygon(black, 2, face...)
	
	eye := circle(12, 16, midpoint.Add(image.Pt(-40, -30)))
	canvas.FillPolygon(black, eye...)
	eye = circle(12, 16, midpoint.Add(image.Pt(40, -30)))
	canvas.FillPolygon(black, eye...)

	mouth := circle(16, 70, midpoint)
	canvas.StrokePolygon(black, 2, mouth[1:8]...)
	
	file, err := os.Create("TEST.png")
	if err != nil { panic(err.Error()) }
	defer file.Close()
	err = png.Encode(file, img)
	if err != nil { panic(err.Error()) }
	
	println("Open TEST.png to see the result.")
}
	
func circle (resolution int, radius float64, center image.Point) []image.Point {
	points := make([]image.Point, resolution)
	for index := range points {
		angle := float64(index) * ((2 * math.Pi) / float64(len(points)))
		point := image.Pt (
			int(math.Cos(angle) * radius),
			int(math.Sin(angle) * radius))
		points[index] = point.Add(center)
	}
	return points
}
